"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var rxjs_1 = require("rxjs");
var CfReceiverService = /** @class */ (function () {
    function CfReceiverService(config) {
        this.config = config;
        console.log('starting CfReceiverService');
        this.setDefaultConfig();
    }
    /**
     * open connection to the WebSocket end point
     */
    CfReceiverService.prototype.watch = function () {
        var _this = this;
        return new rxjs_1.Observable(function (obser) {
            console.log("watch for data from  " + _this.config.endPoint + "/" + _this.config.workflowID);
            _this.connect(obser);
        });
    };
    CfReceiverService.prototype.close = function () {
        this.ws.close();
    };
    CfReceiverService.prototype.connect = function (obser) {
        var _this = this;
        this.log('connecting to WebSocket');
        this.ws = new WebSocket(this.config.endPoint + "/" + this.config.workflowID);
        this.ws.onopen = function () {
            obser.next({
                type: 'start'
            });
        };
        this.ws.onerror = function (event) {
            obser.next({
                type: 'error',
                event: event
            });
            _this.retry(obser);
        };
        this.ws.onclose = function (event) {
            obser.next({
                type: 'close',
                event: event
            });
            _this.retry(obser);
        };
        this.ws.onmessage = function (event) {
            obser.next({
                type: 'message',
                event: event
            });
        };
    };
    CfReceiverService.prototype.retry = function (obser) {
        var _this = this;
        clearTimeout(this.delayRetry);
        this.delayRetry = setTimeout(function () {
            _this.log('try to reconnect to WebSocket');
            _this.connect(obser);
        }, this.config.reconnectDelay);
    };
    CfReceiverService.prototype.setDefaultConfig = function () {
        if (!this.config.debug)
            this.config.debug = true;
        if (!this.config.endPoint)
            throw 'Error -> Missing endPoint value';
        if (!this.config.workflowID)
            throw 'Error -> Missing workflowID value';
        if (!this.config.reconnectDelay)
            this.config.reconnectDelay = 5000;
    };
    CfReceiverService.prototype.log = function (message) {
        if (!this.config.debug)
            return;
        console.log(message);
    };
    return CfReceiverService;
}());
exports.CfReceiverService = CfReceiverService;
//# sourceMappingURL=cfReceiver.service.js.map